# eqc-direct

Qunatum Computing Inc's Dirac device is purpose built to solve computationally hard optimization problems. This package provides an interface to solve problems using Dirac. Dirac devicesare designed to be energy-efficient, robust, and scalable for a wide variety of real-world problems.

## Additional Resources

- [Package Documentation](https://quantumcomputinginc.com/learn/developer-resources/entropy-quantum-optimization/eqc-direct-software-package/latest/getting-started)
- [Dirac-3 Device Info](https://quantumcomputinginc.com/products/dirac-3)
- [Dirac-3 Device User Guide](https://quantumcomputinginc.com/learn/module/introduction-to-dirac-3/dirac-3-user-guide)
- [QCi website](https://quantumcomputinginc.com/)